@@ -1,5 +1,5 @@
 package File::Fu::Base;
-$VERSION = v0.0.6;
+$VERSION = v0.0.7;
 
 use warnings;
 use strict;
@@ -230,6 +230,25 @@ sub chmod :method {
 } # end subroutine chmod definition
 ########################################################################
 
+=head2 rename
+
+Calls the builtin rename() on the $path and returns a new object with
+that name.
+
+  $path = $path->rename($newname);
+
+=cut
+
+sub rename :method {
+  my $self = shift;
+  my ($name) = @_;
+
+  rename($self, $name) or
+    croak("cannot rename '$self' to '$name' $!");
+  return($self->new($name));
+} # end subroutine rename definition
+########################################################################
+
 =head1 Stat Object
 
 The stat() and lstat() methods both return a File::stat object.
